==> kdepim-3.4.2.tar.bz2: kdepim-3.4.2/kmail/interfaces/observer.h <==
/*  -*- mode: C++; c-file-style: "gnu" -*-
    observer.h

    This file is part of KMail's plugin interface.
    Copyright (c) 2004 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KMAIL_INTERFACES_OBSERVER_H__
#define __KMAIL_INTERFACES_OBSERVER_H__

namespace KMail {
  namespace Interface {

    class Observable;

    /**
       @short observer interface
    */
    class Observer {
    public:
      virtual ~Observer() {}

      virtual void update( Observable * obs ) = 0;
    };

  } // namespace Interface

} // namespace KMail

#endif // __KMAIL_INTERFACES_OBSERVER_H__

==> kdepim-4.3.3.tar.bz2: kdepim-4.3.3/kmail/interfaces/observer.h <==
/*  -*- mode: C++; c-file-style: "gnu" -*-
    observer.h

    This file is part of KMail's plugin interface.
    Copyright (c) 2004 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KMAIL_INTERFACES_OBSERVER_H__
#define __KMAIL_INTERFACES_OBSERVER_H__

namespace KMail {
  namespace Interface {

    class Observable;

    /**
       @short observer interface
    */
    class Observer {
    public:
      virtual ~Observer() {}

      virtual void update( Observable * obs ) = 0;
    };

  } // namespace Interface

} // namespace KMail

#endif // __KMAIL_INTERFACES_OBSERVER_H__
